@@ -1,5 +1,4 @@
 import os
-import sys
 import time
 import pickle
 import signal
@@ -16,18 +15,17 @@ supported = False
 mp_context = None
 
 
-if sys.version_info.major > 2 and sys.version_info.minor > 3:
-    methods = multiprocessing.get_all_start_methods()
-    if 'fork' in methods:
-        try:
-            mp_context = multiprocessing.get_context('fork')
+methods = multiprocessing.get_all_start_methods()
+if 'fork' in methods:
+    try:
+        mp_context = multiprocessing.get_context('fork')
 
-            if mp_context.get_start_method() == 'fork':
-                supported = True
-        except RuntimeError:  # child process
-            pass
-else:
-    supported = True
+        if mp_context.get_start_method() == 'fork':
+            supported = True
+        else:
+            raise Exception(mp_context.get_start_method())
+    except RuntimeError:  # child process
+        pass
 
 
 def not_decorated(argument, keyword_argument=0):
@@ -145,6 +143,11 @@ class ProcessConcurrentSub2(ProcessConcurrentObj):
         return 2 + 2
 
 
+class CallableClass:
+    def __call__(self, argument, keyword_argument=0):
+        return argument + keyword_argument
+
+
 @unittest.skipIf(not supported, "Start method is not supported")
 class TestProcessConcurrent(unittest.TestCase):
     def setUp(self):
@@ -307,3 +310,10 @@ class TestProcessConcurrent(unittest.TestCase):
         f = daemon_keyword_decorated()
         dec_out = f.result()
         self.assertEqual(dec_out, False)
+
+    def test_callable_objects(self):
+        """Callable objects are correctly handled."""
+        callable_object = concurrent.process(context=mp_context)(CallableClass())
+        f = callable_object(1)
+
+        self.assertEqual(f.result(), 1)
